@@ -7,6 +7,8 @@ extern "C" {
 
 #include "../application.h"
 
+#include <stdint.h>
+
 typedef struct {
 	bw_Application* app;
 	bw_ApplicationReadyFn func;
@@ -16,12 +18,13 @@ typedef struct {
 
 
 BOOL bw_ApplicationImpl_dispatch( bw_Application* app, bw_ApplicationDispatchData* data );
+BOOL bw_ApplicationImpl_dispatchDelayed( bw_Application* app, bw_ApplicationDispatchData* data, uint64_t milliseconds );
 void bw_ApplicationImpl_finish( bw_ApplicationImpl* );
 int bw_ApplicationImpl_run( bw_Application* app, bw_ApplicationImpl_ReadyHandlerData* ready_handler_data );
 bw_ApplicationImpl bw_ApplicationImpl_initialize( bw_Application* app, int argc, char** argv, const bw_ApplicationSettings* settings );
 
 void bw_ApplicationEngineImpl_finish( bw_ApplicationEngineImpl* );
-bw_ApplicationEngineImpl bw_ApplicationEngineImpl_initialize( bw_Application* app, int argc, char** argv, const bw_ApplicationSettings* settings );
+bw_Err bw_ApplicationEngineImpl_initialize( bw_ApplicationEngineImpl* impl, bw_Application* app, int argc, char** argv, const bw_ApplicationSettings* settings );
 
 
 
