@@ -23,10 +23,15 @@ typedef struct {
 	DWORD thread_id;
 	HINSTANCE handle;
 	WNDCLASSEXW wc;
-	bool is_running;
 	SRWLOCK is_running_mtx;
 } bw_ApplicationImpl;
 
+typedef struct {
+	void* dispatch_data;
+	UINT delay;
+	struct bw_Application* app;
+} bw_ApplicationDispatchDelayedData;
+
 
 
 #ifdef __cplusplus
